#ifndef NT2_INCLUDE_CONSTANTS_I_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_I_HPP_INCLUDED

#include <nt2/complex/include/constants/i.hpp>

#endif
